@@ -124,6 +124,10 @@ class Plugin(GlancesPlugin):
                         config.as_dict()['processlist']['sort_key']))
                 glances_processes.set_sort_key(config.as_dict()['processlist']['sort_key'], False)
 
+        # The default sort key could also be overwrite by command line (see #1903)
+        if args.sort_processes_key is not None:
+            glances_processes.set_sort_key(args.sort_processes_key, False)
+
         # Note: 'glances_processes' is already init in the processes.py script
 
     def get_key(self):
